@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::WordList;
 
 our $DATE = '2016-01-13'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 use 5.010001;
 use strict;
@@ -57,6 +57,7 @@ sub munge_files {
                     $stats{num_words_contains_whitespace}++ if $word =~ /\s/;
                     $stats{num_words_contains_nonword_chars}++ if $word =~ /\W/;
                     my $len = length($word);
+                    $total_len += $len;
                     $stats{shortest_word_len} = $len
                         if !defined($stats{shortest_word_len}) ||
                         $len < $stats{shortest_word_len};
@@ -64,6 +65,7 @@ sub munge_files {
                         if !defined($stats{longest_word_len}) ||
                         $len > $stats{longest_word_len};
                 });
+            $stats{avg_word_len} = $total_len / $stats{num_words} if $total_len;
 
             $content =~ s{^(#\s*STATS)$}{"our \%STATS = ".dmp(%stats)."; " . $1}em
                 or die "Can't replace #STATS for ".$file->name.", make sure you put the #STATS placeholder in modules";
@@ -93,7 +95,7 @@ Dist::Zilla::Plugin::WordList - Plugin to use when building WordList::* distribu
 
 =head1 VERSION
 
-This document describes version 0.01 of Dist::Zilla::Plugin::WordList (from Perl distribution Dist-Zilla-Plugin-WordList), released on 2016-01-13.
+This document describes version 0.02 of Dist::Zilla::Plugin::WordList (from Perl distribution Dist-Zilla-Plugin-WordList), released on 2016-01-13.
 
 =head1 SYNOPSIS
 
